#!/usr/bin/env python3
import subprocess
from argparse import ArgumentParser
from os import path
from subprocess import getstatusoutput

# 定义常量

EXIT_SUCCESS = 0
EXIT_FAILURE = 3


def safe_int_conversion(value):
	"""安全地将字符串转换为整数，忽略无法转换的情况"""
	try:
		return int(value)
	except ValueError:
		return None


def execute_command(command):
	"""安全地执行命令并返回结果"""
	try:
		result = subprocess.getstatusoutput(command)
		return result
	except Exception as e:
		print(f"命令执行异常: {e}")
		return EXIT_FAILURE, None


def stop_process_by_name(process_name):
	res = getstatusoutput(f"pgrep {process_name}")
	if res[0] == 0:
		print(f"[ {process_name} ]进程存在[ {res[1]}]，正在停止...")
		c = f"kill -9 {res[1]} "
		print(c)
		kill = getstatusoutput(c)
		if kill[0] == 0:
			print(f"[ {process_name} ]进程停止成功")
			return EXIT_SUCCESS
		else:
			print(f"[ {process_name} ]进程停止失败")
			return EXIT_FAILURE


def stop():
	# 尝试停止 run.sh 启动的进程
	res = stop_process_by_name("ttrun.sh")
	if res != EXIT_SUCCESS:
		return res

	# 尝试停止二进制进程
	res = stop_process_by_name(bin_)
	if res != EXIT_SUCCESS:
		return res

	return EXIT_SUCCESS


if __name__ == '__main__':
	arg = ArgumentParser(description='当前脚本版本: 1.0', prog="二进制业务停止脚本")
	h = '设置执行文件路径'
	arg.add_argument('-b', '--bin', type=str, help=h, required=True)
	h = '设置缓存目录'
	arg.add_argument('-r', '--run', type=str, help=h, required=True)
	args = arg.parse_args()
	bin_ = args.bin
	bin_ = path.basename(bin_)
	run_ = args.run
	run_ = path.basename(run_)
	stop()
